gitpython: GitPython is a python library used to interact with Git repositories
===============================================================================

Description
-----------

GitPython is a python library used to interact with Git repositories

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/GitPython/

